@@ -123,7 +123,7 @@ def check_bathy(Temp, bthA, bthD, depth):
 def T68conv(T90):
     return T90 * 1.00024
 
-def dens0(s,t):
+def dens0(t,s=0.2):
     b = (8.24493e-1, -4.0899e-3, 7.6438e-5, -8.2467e-7, 5.3875e-9)
     c = (-5.72466e-3, 1.0227e-4, -1.6546e-6)
     d = 4.8314e-4
